# Columns

This section contains the existing steps intended to be used for common column operations to apply to the batches.

::: distilabel.steps.columns.expand
::: distilabel.steps.columns.keep
::: distilabel.steps.columns.merge
::: distilabel.steps.columns.group
